@@ -1,10 +1,10 @@
 package Net::DNS::RR::DNSKEY;
 
 #
-# $Id: DNSKEY.pm 1167 2014-02-03 09:55:08Z willem $
+# $Id: DNSKEY.pm 1271 2014-10-10 21:55:38Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1167 $)[1];
+$VERSION = (qw$LastChangedRevision: 1271 $)[1];
 
 
 use strict;
@@ -19,6 +19,7 @@ Net::DNS::RR::DNSKEY - DNS DNSKEY resource record
 
 use integer;
 
+use warnings;
 use Carp;
 use MIME::Base64;
 
@@ -81,17 +82,16 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 sub encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{algorithm};
-	pack 'n C2 a*', $self->flags, $self->protocol, $self->algorithm, $self->keybin;
+	my $keybin = $self->keybin || return '';
+	pack 'n C2 a*', $self->flags, $self->protocol, $self->algorithm, $keybin;
 }
 
 
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $keybin = $self->keybin || return '';
+	my $base64 = MIME::Base64::encode $self->keybin || return '';
 	my @params = map $self->$_, qw(flags protocol algorithm);
-	my $base64 = MIME::Base64::encode $keybin;
 	chomp $base64;
 	return join ' ', @params, "(\n$base64 ) ; Key ID =", $self->keytag;
 }
@@ -101,7 +101,7 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->$_(shift) for qw(flags protocol algorithm);
-	$self->publickey(@_);
+	$self->key(@_);
 }
 
 
@@ -259,11 +259,8 @@ sub sep {
 }
 
 
-my $warned;
-
 sub is_sep {				## historical
 	my $self = shift;
-	carp "Deprecated method: please use rr->sep(@_)" unless $warned++;
 	return $self->sep(@_) ? 1 : 0;
 }
 
@@ -331,8 +328,9 @@ The format depends on the algorithm of the key being stored.
     $privatekeyname=$rr->privatekeyname
 
 Returns the name of the privatekey as it would be generated by
-the BIND dnssec-keygen program. The format of that name being
-K\<fqdn\>+\<algorithm\>+\<keyid\>.private
+the BIND dnssec-keygen program. The format of that name being:
+
+	K<fqdn>+<algorithm>+<keyid>.private
 
 =head2 keylength
 
@@ -342,7 +340,7 @@ Returns the length (in bits) of the modulus calculated from the key text.
 
     print "keytag = ", $rr->keytag, "\n";
 
-Returns the key tag of the key. (RFC2535 4.1.6)
+Returns the 16-bit numerical key tag of the key. (RFC2535 4.1.6)
 
 =head2 zone
 
