@@ -1,10 +1,10 @@
 package Net::DNS::RR::DS;
 
 #
-# $Id: DS.pm 1271 2014-10-10 21:55:38Z willem $
+# $Id: DS.pm 1302 2015-01-23 11:07:41Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1271 $)[1];
+$VERSION = (qw$LastChangedRevision: 1302 $)[1];
 
 
 use strict;
@@ -136,7 +136,7 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{digtype};
-	my @babble = ( "\n;", $self->babble ) if BABBLE;
+	my @babble = BABBLE ? ( "\n;", $self->babble ) : ();
 	my $digest = $self->digest;
 	$digest = join( "\n", '(', split /(\S{64})/, $digest ) . ' )' if length $digest > 40;
 	join ' ', @{$self}{qw(keytag algorithm digtype)}, $digest, @babble;
@@ -204,8 +204,7 @@ sub digestbin {
 
 
 sub babble {
-	return Digest::BubbleBabble::bubblebabble( Digest => shift->digestbin ) if BABBLE;
-	return '';
+	return BABBLE ? Digest::BubbleBabble::bubblebabble( Digest => shift->digestbin ) : '';
 }
 
 
