@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3;
 
 #
-# $Id: NSEC3.pm 1179 2014-03-19 21:46:58Z willem $
+# $Id: NSEC3.pm 1302 2015-01-23 11:07:41Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1179 $)[1];
+$VERSION = (qw$LastChangedRevision: 1302 $)[1];
 
 
 use strict;
@@ -109,7 +109,8 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	$self->algorithm(shift);
 	$self->flags(shift);
 	$self->iterations(shift);
-	$self->salt(shift);
+	my $salt = shift;
+	$self->salt($salt) unless $salt eq '-';
 	$self->hnxtname(shift);
 	$self->typelist(@_);
 }
@@ -234,7 +235,6 @@ sub optout {
 
 ########################################
 
-
 sub hashalgo {				## historical
 	&algorithm;
 }
@@ -253,26 +253,21 @@ sub name2hash {
 
 	my $arglist = $digest{$hashalg} || die 'unsupported hash algorithm';
 	my ( $object, @argument ) = @$arglist;
-
-	my $hashfunc = sub {
-		my $hash = $object->new(@argument);
-		$hash->add(shift);
-		$hash->add($salt);
-		return $hash->digest;
-	};
+	my $hash = $object->new(@argument);
 
 	my $wirename = new Net::DNS::DomainName($name)->encode;
-	$wirename = &$hashfunc($wirename);
+	$iterations++;
 
 	while ( $iterations-- > 0 ) {
-		$wirename = &$hashfunc($wirename);
+		$hash->add($wirename);
+		$hash->add($salt);
+		$wirename = $hash->digest;
 	}
 
 	my $base32hex = MIME::Base32::encode( $wirename, '' );	# [0-9 A-V]	per RFC4648, 7.
 	return lc $base32hex;
 }
 
-
 1;
 __END__
 
@@ -337,9 +332,9 @@ integer.  The value is between 0 and 65535, inclusive.
     $salt = $rr->salt;
     $rr->salt( $salt );
 
-The Salt field is represented by a contiguous sequence of hexadecimal
-digits. This field is represented as "-" (without quotes) when the
-used in string format to indicate that the salt field is absent. 
+The Salt field is represented as a contiguous sequence of hexadecimal
+digits. A "-" (unquoted) is used in string format to indicate that the
+salt field is absent. 
 
 =head2 saltbin
 
