@@ -1,11 +1,11 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1303 2015-01-23 11:09:21Z willem $
+# $Id: SEC.pm 1305 2015-01-26 08:26:02Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '0.21_06';
-$SVNVERSION = (qw$LastChangedRevision: 1303 $)[1];
+$VERSION    = '0.21_07';
+$SVNVERSION = (qw$LastChangedRevision: 1305 $)[1];
 
 
 =head1 NAME
@@ -18,15 +18,15 @@ Net::DNS::SEC - DNSSEC extensions to Net::DNS
 
 =head1 DESCRIPTION
 
-The Net::DNS::SEC suite provides the additional DNS resource records
-required to support DNSSEC as described in RFC4033, 4034, 4035 and
-subsequent related documents.
+The Net::DNS::SEC suite provides additional packages required to support
+DNSSEC as described in RFC4033, RFC4034, RFC4035 and subsequent related
+documents.
 
 Net::DNS::SEC is installed as an extension to an existing Net::DNS
 installation.
 
-The extended package features are made visible by substituting
-Net::DNS::SEC for Net::DNS in the use declaration.
+The extended features are made available by substituting Net::DNS::SEC
+for Net::DNS in the use declaration.
 
 =cut
 
@@ -45,8 +45,10 @@ use warnings;
 use Carp;
 
 require Net::DNS::RR::DS;
-
-new Net::DNS::RR( type => $_ ) for qw(SIG RRSIG DS CDS DLV);	# pre-load RR with create() constructor
+require Net::DNS::RR::CDS;
+require Net::DNS::RR::DLV;
+require Net::DNS::RR::RRSIG;
+require Net::DNS::RR::SIG;
 
 
 =head1 UTILITY FUNCTIONS
@@ -89,16 +91,15 @@ Fills @result with all keys in array @a that are not in array @b.
 
 =cut
 
-my $errmsg = 'array argument contains unexpected %s object';
-
 sub key_difference {
 	my $a = shift;
 	my $b = shift;
-	my $r = shift;			## 0.17 interface
 
 	my ($x) = grep !$_->isa('Net::DNS::RR::DNSKEY'), @$a, @$b;
 
-	if ($r) {			## 0.17 interface
+	if (@_) {			## 0.17 interface
+		my $r = shift || [];
+		my $errmsg = 'array argument contains unexpected %s object';
 		return sprintf $errmsg, ref($x) if $x;
 
 		my %index = map { ( $_->privatekeyname, 1 ) } @$b;
@@ -106,10 +107,10 @@ sub key_difference {
 		return (0);
 	}
 
-	croak sprintf $errmsg, ref($x) if $x;
+	croak sprintf 'key list contains unexpected %s object', ref($x) if $x;
 
-	my %index = map { ( $_->privatekeyname, 1 ) } @$b;
-	my @r = grep { !$index{$_->privatekeyname} } @$a;
+	my %index = map { ( $_->privatekeyname => 1 ) } @$b;
+	my @r = grep !$index{$_->privatekeyname}, @$a;
 	return @r;
 }
 
@@ -120,7 +121,9 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright (c)2001-2005 RIPE NCC.  Author Olaf M. Kolkman
+Copyright (c)2001-2005 RIPE NCC. Author Olaf M. Kolkman
+
+Portions Copyright (c)2014-2015  Dick Franks
 
 All Rights Reserved
 
@@ -146,11 +149,7 @@ THIS SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR::DNSKEY>, L<Net::DNS::RR::DS>,
-L<Net::DNS::RR::NSEC>, L<Net::DNS::RR::NSEC3>, L<Net::DNS::RR::NSEC3PARAM>,
-L<Net::DNS::RR::RRSIG>, L<Net::DNS::RR::KEY>, L<Net::DNS::RR::SIG>,
-L<Net::DNS::RR::CDS>, L<Net::DNS::RR::CDNSKEY>, L<Net::DNS::RR::DLV>,
-RFC4033, RFC4034, RFC4035
+L<perl>, L<Net::DNS>, RFC4033, RFC4034, RFC4035
 
 =cut
 
